@@ -104,7 +104,7 @@ def GetStringPosition(str,fnd):
     pos += str.find(fnd)
     return pos
 
-def GetUniqueItem(list_values):
+def GetUniqueItems(list_values):
   """
   Returns the unique list of values from parameter list_values
   """
